# [[file:../arroyo-native-parser.org::*Click command wrapper][Click command wrapper:1]]
import os
import click
import glob
from typing import Optional

# from . import persist_one_file
from .arroyo_rs import parse_file, htmlize_file, ExportOptions
# from . import models
# from sqlmodel import Session
# Click command wrapper:1 ends here

# [[file:../arroyo-native-parser.org::*Click command wrapper][Click command wrapper:2]]
@click.group()
def cli():
  pass

@cli.command()
@click.option("--source", "-s", help="Org source directory", default="~/org")
@click.option("--file-glob", "-g", help="File search glob", default="**/*.org")
def parse_files(source, file_glob):
  expanded_src = os.path.expanduser(source)
  files = glob.glob(file_glob, root_dir=expanded_src, recursive=True)
  files = map(lambda it: os.path.join(expanded_src, it), files)
  files = list(filter(os.path.isfile, files))

  docs = [
    parse_file(f)
    for f in files
  ]

  print(f"Parsed {len(files)} files.")
  print(f"Persisted {len(docs)} docs.")


@cli.command()
@click.option("--file", "-f", help="The file to export")
@click.option("--limit-headings", "-H", multiple=True, help="org ID to export")
@click.option("--include-subheadings", "-I", help="when headings are specified, this will control whether to export child headings")
def export_document(file, limit_headings: Optional[set] = None, include_subheadings=False):
  # in The Real World this is loaded from DB and generated.
  options = ExportOptions(
    link_retargets = {"currently_reading": "https://rix.si/hello-world"},
    limit_headings = limit_headings,
    include_subheadings = include_subheadings,
    ignore_tags = ["NOEXPORT", "noexport", "private"],
  )
  print(htmlize_file(file, options))
# Click command wrapper:2 ends here

# [[file:../arroyo-native-parser.org::*Click command wrapper][Click command wrapper:3]]
if __name__ == "__main__":
  cli()
# Click command wrapper:3 ends here
